Trait security_framework::os::macos::identity::SecIdentityExt [−][src]
pub trait SecIdentityExt {
fn with_certificate(
keychains: &[SecKeychain],
certificate: &SecCertificate
) -> Result<SecIdentity>;
}Expand description
An extension trait adding OSX specific functionality to SecIdentity.
Required methods
fn with_certificate(
keychains: &[SecKeychain],
certificate: &SecCertificate
) -> Result<SecIdentity>[src]
fn with_certificate(
keychains: &[SecKeychain],
certificate: &SecCertificate
) -> Result<SecIdentity>[src]Creates an identity corresponding to a certificate, looking in the provided keychains for the corresponding private key.
Implementors
impl SecIdentityExt for SecIdentity[src]
impl SecIdentityExt for SecIdentity[src]fn with_certificate(
keychains: &[SecKeychain],
certificate: &SecCertificate
) -> Result<SecIdentity>[src]
keychains: &[SecKeychain],
certificate: &SecCertificate
) -> Result<SecIdentity>